"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var JsDiff = require("diff");
function markdownDiff(oldStr, newStr) {
    var output = [];
    var parts = JsDiff.diffChars(oldStr, newStr);
    for (var _i = 0, parts_1 = parts; _i < parts_1.length; _i++) {
        var part = parts_1[_i];
        var value = part.value;
        var prefix = part.added ? '<ins>' : part.removed ? '<del>' : '';
        var posfix = part.added ? '</ins>' : part.removed ? '</del>' : '';
        if (isTable(part)) {
            output.push(tableDiff(value, prefix, posfix));
        }
        else if (isList(part)) {
            output.push(listDiff(value, prefix, posfix));
        }
        else {
            output.push("" + prefix + value + posfix);
        }
    }
    return output.join('');
}
exports.markdownDiff = markdownDiff;
function isList(part) {
    var listRegex = new RegExp('^([\r\n\t ]*)(\\*|-|\\+)');
    return (part.added || part.removed) && listRegex.test(part.value);
}
function listDiff(value, prefix, posfix) {
    var regex = new RegExp('^([\r\n\t ]*)(\\*|-|\\+)([ ]*)(.*)$', 'gm');
    var out = [];
    var match = regex.exec(value);
    while (match !== null) {
        var spaces = match[1];
        var listOp = match[2];
        var afterOpSpaces = match[3];
        var content = match[4];
        out.push("" + spaces + listOp + afterOpSpaces + prefix + content + posfix);
        match = regex.exec(value);
    }
    return out.join('\n');
}
function isTable(part) {
    return (part.added || part.removed) && part.value.indexOf('|') !== -1;
}
function tableDiff(value, prefix, posfix) {
    var out = [];
    var split = value.split('|');
    var startWithPipe = split[0].length === 0 ? '|' : '';
    var endsWithPipe = split[split.length - 1].length === 0 ? '|' : '';
    var filtered = split.filter(function (el) { return el.length !== 0; });
    for (var _i = 0, filtered_1 = filtered; _i < filtered_1.length; _i++) {
        var val = filtered_1[_i];
        out.push("" + prefix + val + posfix);
    }
    return startWithPipe + out.join('|') + endsWithPipe;
}
//# sourceMappingURL=index.js.map